@@ -6,7 +6,7 @@ import requests
 
 class RatesNotAvailableError(Exception):
     """
-    Custome Exception when http://fixer.io/ is Down are not available for currency rates
+    Custome Exception when https://ratesapi.io is Down and not available for currency rates
     """
     pass
 
@@ -24,7 +24,7 @@ class Common:
         self._force_decimal = force_decimal
 
     def _source_url(self):
-        return "http://api.fixer.io/"
+        return "https://ratesapi.io/api/"
 
     def _get_date_string(self, date_obj):
         if date_obj is None:
@@ -56,6 +56,10 @@ class CurrencyRates(Common):
         raise RatesNotAvailableError("Currency Rates Source Not Ready")
 
     def get_rate(self, base_cur, dest_cur, date_obj=None):
+        if base_cur == dest_cur:
+            if self._force_decimal:
+                return Decimal(1)
+            return 1.
         date_str = self._get_date_string(date_obj)
         payload = {'base': base_cur, 'symbols': dest_cur}
         source_url = self._source_url() + date_str
@@ -73,6 +77,12 @@ class CurrencyRates(Common):
             use_decimal = True
         else:
             use_decimal = self._force_decimal
+
+        if base_cur == dest_cur:  # Return same amount if both base_cur, dest_cur are same
+            if use_decimal:
+                return Decimal(amount)
+            return float(amount)
+
         date_str = self._get_date_string(date_obj)
         payload = {'base': base_cur, 'symbols': dest_cur}
         source_url = self._source_url() + date_str
